@@ -93,7 +93,11 @@ class Project {
    */
   public static function buildFetchUrl(array $request) {
     $status_url = isset($request['status url']) ? $request['status url'] : ReleaseInfo::DEFAULT_URL;
-    return $status_url . '/' . $request['name'] . '/' . $request['drupal_version'];
+    $drupal_version = $request['drupal_version'];
+    if ($drupal_version == '9.x') {
+      $drupal_version = 'all';
+    }
+    return $status_url . '/' . $request['name'] . '/' . $drupal_version;
   }
 
   /**
@@ -235,6 +239,12 @@ class Project {
       $releases[$release_info['version']] = $release_info;
     }
 
+    // If there's no "Recommended major version", we want to recommend
+    // the most recent release.
+    if (!$recommended_major) {
+      $latest_version = key($releases);
+    }
+
     // If there is no -stable- release in the recommended major,
     // then take the latest version in the recommended major to be
     // the recommended release.
@@ -299,7 +309,7 @@ class Project {
    *
    * @return array|bool
    */
-  private static function getBestRelease(array $releases) {
+  public static function getBestRelease(array $releases) {
     if (empty($releases)) {
       return FALSE;
     }
@@ -324,7 +334,7 @@ class Project {
   private function searchReleases($key, $value) {
     $releases = array();
     foreach ($this->parsed['releases'] as $version => $release) {
-      if ($release['status'] == 'published' && isset($release[$key]) && $release[$key] == $value) {
+      if ($release['status'] == 'published' && isset($release[$key]) && strcmp($release[$key], $value) == 0) {
         $releases[$version] = $release;
       }
     }
@@ -387,10 +397,12 @@ class Project {
     if ($recommended_major != 0) {
       $majors[] = $this->parsed['recommended_major'];
     }
-    $supported = explode(',', $this->parsed['supported_majors']);
-    foreach ($supported as $v) {
-      if ($v != $recommended_major) {
-        $majors[] = $v;
+    if (!empty($this->parsed['supported_majors'])) {
+      $supported = explode(',', $this->parsed['supported_majors']);
+      foreach ($supported as $v) {
+        if ($v != $recommended_major) {
+          $majors[] = $v;
+        }
       }
     }
     $releases = array();
